@@ -1,10 +1,8 @@
 # Copyright 2017 Palantir Technologies, Inc.
 import os
 import pytest
-import shutil
-import tempfile
 from pyls import uris
-from pyls.workspace import Document, Workspace
+from pyls.workspace import Document
 from pyls.plugins.references import pyls_references
 
 
@@ -17,17 +15,17 @@ DOC1 = """class Test1():
 
 DOC2 = """from test1 import Test1
 
-Test1()
+try:
+    Test1()
+except UnicodeError:
+    pass
 """
 
 
 @pytest.fixture
-def tmp_workspace():
-    tmp = tempfile.mkdtemp()
-    workspace = Workspace(uris.from_fs_path(tmp))
-
+def tmp_workspace(workspace):
     def create_file(name, content):
-        fn = os.path.join(tmp, name)
+        fn = os.path.join(workspace.root_path, name)
         with open(fn, 'w') as f:
             f.write(content)
         workspace.put_document(uris.from_fs_path(fn), content)
@@ -35,11 +33,10 @@ def tmp_workspace():
     create_file(DOC1_NAME, DOC1)
     create_file(DOC2_NAME, DOC2)
 
-    yield workspace
-    shutil.rmtree(tmp)
+    return workspace
 
 
-def test_references(tmp_workspace):
+def test_references(tmp_workspace):  # pylint: disable=redefined-outer-name
     # Over 'Test1' in class Test1():
     position = {'line': 0, 'character': 8}
     DOC1_URI = uris.from_fs_path(os.path.join(tmp_workspace.root_path, DOC1_NAME))
@@ -65,5 +62,18 @@ def test_references(tmp_workspace):
     assert doc2_import_ref['range']['end'] == {'line': 0, 'character': 23}
 
     doc2_usage_ref = [u for u in refs if u['uri'] != DOC1_URI][1]
-    assert doc2_usage_ref['range']['start'] == {'line': 2, 'character': 0}
-    assert doc2_usage_ref['range']['end'] == {'line': 2, 'character': 5}
+    assert doc2_usage_ref['range']['start'] == {'line': 3, 'character': 4}
+    assert doc2_usage_ref['range']['end'] == {'line': 3, 'character': 9}
+
+
+def test_references_builtin(tmp_workspace):  # pylint: disable=redefined-outer-name
+    # Over 'UnicodeError':
+    position = {'line': 4, 'character': 7}
+    doc2_uri = uris.from_fs_path(os.path.join(tmp_workspace.root_path, DOC2_NAME))
+    doc2 = Document(doc2_uri)
+
+    refs = pyls_references(doc2, position)
+    assert len(refs) >= 1
+
+    assert refs[0]['range']['start'] == {'line': 4, 'character': 7}
+    assert refs[0]['range']['end'] == {'line': 4, 'character': 19}
